@@ -10,7 +10,7 @@ with (
     'Dist::Zilla::Role::PluginBundle::Config::Slicer',
 );
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
  
 sub configure {
     my ($self) = @_;
@@ -23,11 +23,8 @@ sub configure {
     $self->add_plugins(qw(
         Git::GatherDir
         Prereqs::FromCPANfile
+        PodWeaver
     ));
-    $self->add_plugins(
-        # Don't try to weave scripts. They have their own POD.
-        [ PodWeaver => { finder => ':InstallModules' } ],
-    );
     $self->add_bundle('@Starter', {
         '-remove' => [ 'GatherDir', 'UploadToCPAN', 'TestRelease', @$remove ],
     });
@@ -130,6 +127,20 @@ It is roughly equivalent to:
   -type  = requires
   Test::More = 0.96
 
+Your module files should contain:
+
+  # ABSTRACT: frobnicates the whirligigs
+
+  our $VERSION = '0.001';
+
+For PodWeaver (the ABSTRACT) and RewriteVersion (the $VERSION).
+
+Your script files should additionally contain
+
+  # PODNAME: myscript
+
+Modules and scripts should thus not contain a NAME section in their POD.
+
 =head1 TODO
 
 The two modules in this distribution need to be split into roles so we don't
